@@ -10,7 +10,7 @@ use Carp ();
 use constant DEBUG => $ENV{MOJO_REDIS_DEBUG} || 0;
 use constant DEFAULT_PORT => 6379;
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 my $PROTOCOL_CLASS = do {
   my $class = $ENV{MOJO_REDIS_PROTOCOL}
@@ -198,7 +198,7 @@ sub _error {
   return if $self->{destroy};
   return $self->_requeue($c)->_connect($c) unless defined $err;
   return $self->emit(error => $err) unless @$waiting;
-  return $self->$_($err, undef) for grep {$_} map { $_->[0] } @$waiting;
+  $self->$_($err, undef) for grep {$_} map { $_->[0] } @$waiting;
 }
 
 sub _execute {
@@ -340,7 +340,7 @@ Mojo::Redis2 - Pure-Perl non-blocking I/O Redis driver
 
 =head1 VERSION
 
-0.31
+0.32
 
 =head1 DESCRIPTION
 
@@ -433,16 +433,12 @@ the same Redis server. It will also re-use the same connection when you
   get '/' => sub {
     my $c = shift;
 
-    $c->delay(
-      sub {
-        my ($delay) = @_;
-        $c->redis->get('some:message', $delay->begin);
-      },
-      sub {
-        my ($delay, $err, $message) = @_;
-        $c->render(json => { error => $err, message => $message });
-      },
-    );
+    my $tx = $c->render_later->tx;
+    $c->redis->get('some:message', sub {
+      my ($redis, $err, $message) = @_;
+      $c->render(json => { error => $err, message => $message });
+      undef $tx;
+    });
   };
 
   app->start;
